@@ -33,7 +33,10 @@ class Worker(Thread):
             except KeyboardInterrupt:
                 return
             finally:
-                self.queue.task_done()
+                try:
+                    self.queue.task_done()
+                except EOFError:
+                    return
 
 
 class ThreadPool(object):
@@ -47,10 +50,11 @@ class ThreadPool(object):
             worker.start()
 
     def is_alive(self):
-        return any(w.running for w in self.workers)
+        return any(w.is_alive() for w in self.workers)
 
     def join(self, nowait=False):
         for worker in (w for w in self.workers if w.is_alive()):
             if nowait:
                 worker.running = False
             worker.join(0)
+            time.sleep(0)
